==> guiloader-2.12.0.tar.bz2: guiloader-2.12.0/examples/typical/application.h <==
/*
 *  GuiLoader examples
 *  Copyright (c) 2006-2008 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef EXAMPLE_APPLICATION_H
#define EXAMPLE_APPLICATION_H

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <guiloader.h>
#include <string.h>

typedef struct _Application Application;

struct _Application {
	GuiLoader * loader;

	gchar * file;
	gboolean modified;
	gboolean lock;

	GtkWindow * window;
	GtkActionGroup * actions;
	GtkTextView * textView;
	GtkStatusbar * statusbar;

	GtkFileChooserDialog * openDialog;
	GtkFileChooserDialog * saveDialog;
	GtkDialog * proceedDialog;
};

void ApplicationInit(Application * app);
void ApplicationDone(Application * app);

void UpdateUi(Application * app);
void SetText(Application * app, const gchar * text);
gchar * GetText(Application * app);
void SetFile(Application * app, gchar * str);

void OnChanged(GtkTextBuffer * textbuffer, Application * app);
void OnMarkSet(GtkTextBuffer * textbuffer, GtkTextIter * arg1, GtkTextMark * arg2, Application * app);
void OnNew(GtkAction * action, Application * app);
void OnOpen(GtkAction * action, Application * app);
void OnSave(GtkAction * action, Application * app);
void OnSaveAs(GtkAction * action, Application * app);
void OnQuit(GtkAction * action, Application * app);
void OnCut(GtkAction * action, Application * app);
void OnCopy(GtkAction * action, Application * app);
void OnPaste(GtkAction * action, Application * app);
void OnDelete(GtkAction * action, Application * app);
void OnAbout(GtkAction * action, Application * app);
gboolean OnDeleteEvent(GtkWidget * widget, GdkEvent * event, Application * app);

gchar * LoadFile(Application * app, const gchar * name);
gboolean SaveFile(Application * app, const gchar * name, const gchar * data);
gchar * AskFilename(Application * app, GtkFileChooserAction action);
gboolean AskProceed(Application * app);

void ShowMessage(Application * app, const gchar * message);

#endif

==> guiloader-2.13.1.tar.bz2: guiloader-2.13.1/examples/typical/application.h <==
/*
 *  GuiLoader examples
 *  Copyright (c) 2006-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person 
 *  obtaining a copy of this software and associated documentation 
 *  files (the "Software"), to deal in the Software without 
 *  restriction, including without limitation the rights to use, copy, 
 *  modify, merge, publish, distribute, sublicense, and/or sell copies 
 *  of the Software, and to permit persons to whom the Software is 
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind, 
 *  express or implied, including but not limited to the warranties of 
 *  merchantability, fitness for a particular purpose and 
 *  noninfringement. In no event shall the authors or copyright 
 *  holders be liable for any claim, damages or other liability, 
 *  whether in an action of contract, tort or otherwise, arising from, 
 *  out of or in connection with the software or the use or other 
 *  dealings in the software.
 */

#ifndef EXAMPLE_APPLICATION_H
#define EXAMPLE_APPLICATION_H

#ifdef _WIN32
	#include <gdk/gdkwin32.h>
#endif

#include <guiloader.h>
#include <string.h>

typedef struct _Application Application;

struct _Application {
	GuiLoader * loader;

	char * file;
	gboolean modified;
	gboolean lock;

	GtkWindow * window;
	GtkActionGroup * actions;
	GtkTextView * textView;
	GtkStatusbar * statusbar;

	GtkFileChooserDialog * openDialog;
	GtkFileChooserDialog * saveDialog;
	GtkDialog * proceedDialog;
};

void ApplicationInit(Application * app);
void ApplicationDone(Application * app);

void UpdateUi(Application * app);
void SetText(Application * app, const char * text);
char * GetText(Application * app);
void SetFile(Application * app, char * str);

void OnChanged(GtkTextBuffer * textbuffer, Application * app);
void OnMarkSet(GtkTextBuffer * textbuffer, GtkTextIter * arg1, GtkTextMark * arg2, Application * app);
void OnNew(GtkAction * action, Application * app);
void OnOpen(GtkAction * action, Application * app);
void OnSave(GtkAction * action, Application * app);
void OnSaveAs(GtkAction * action, Application * app);
void OnQuit(GtkAction * action, Application * app);
void OnCut(GtkAction * action, Application * app);
void OnCopy(GtkAction * action, Application * app);
void OnPaste(GtkAction * action, Application * app);
void OnDelete(GtkAction * action, Application * app);
void OnAbout(GtkAction * action, Application * app);
gboolean OnDeleteEvent(GtkWidget * widget, GdkEvent * event, Application * app);

char * LoadFile(Application * app, const char * name);
gboolean SaveFile(Application * app, const char * name, const char * data);
char * AskFilename(Application * app, GtkFileChooserAction action);
gboolean AskProceed(Application * app);

void ShowMessage(Application * app, const char * message);

#endif
